@@ -82,7 +82,7 @@
       (bg-green    "#20a020")
       (bg-yellow   "#9a4f20")
       (bg-blue     "#3f43af")
-      (bg-magenta  "#c040cf")
+      (bg-magenta  "#b04fcf")
       (bg-cyan     "#027080")
 
       (bg-red-subtle      "#77002a")
@@ -127,7 +127,7 @@
       (bg-hover-alt  "#6f345a")
       (bg-hl-line    "#302a3a")
       (bg-region     "#3f1020")
-      (bg-paren      "#7f2d40")
+      (bg-paren      "#2f6c4a")
       (bg-err        "#361400") ; check with err
       (bg-warning    "#332800") ; check with warning
       (bg-info       "#152800") ; check with info
