@@ -49,7 +49,7 @@
       (bg-dim      "#e8e8ea")
       (fg-dim      "#70627f")
       (bg-alt      "#d3d3e0")
-      (fg-alt      "#6f6336")
+      (fg-alt      "#196f70")
 
       (bg-active   "#c3c3d0")
       (bg-inactive "#efeff5")
@@ -81,12 +81,12 @@
       (cyan-faint      "#506fa0")
 
       ;; Basic hues for background values
-      (bg-red      "#ff8f88")
-      (bg-green    "#8adf80")
+      (bg-red      "#cac200")
+      (bg-green    "#9aaf80")
       (bg-yellow   "#fac200")
       (bg-blue     "#cbcfff")
-      (bg-magenta  "#ff9fef")
-      (bg-cyan     "#88c8ff")
+      (bg-magenta  "#3fbfff")
+      (bg-cyan     "#98e8ff")
 
       (bg-red-subtle      "#ffcfbf")
       (bg-green-subtle    "#afffbf")
