@@ -6,7 +6,7 @@
 ;; Maintainer: Ef-Themes Development <~protesilaos/ef-themes@lists.sr.ht>
 ;; URL: https://git.sr.ht/~protesilaos/ef-themes
 ;; Mailing-List: https://lists.sr.ht/~protesilaos/ef-themes
-;; Version: 0.5.0
+;; Version: 0.6.0
 ;; Package-Requires: ((emacs "27.1"))
 ;; Keywords: faces, theme, accessibility
 
@@ -48,29 +48,18 @@
 
 ;;; User options
 
-(defconst ef-themes-collection
-  '(ef-autumn
-    ef-dark
-    ef-day
-    ef-deuteranopia-dark
-    ef-deuteranopia-light
-    ef-duo-dark
-    ef-duo-light
-    ef-light
-    ef-night
-    ef-spring
-    ef-summer
-    ef-winter)
-  "Symbols of all the Ef themes.")
-
 (defconst ef-themes-light-themes
-  '(ef-day ef-deuteranopia-light ef-duo-light ef-light ef-spring ef-summer)
+  '(ef-day ef-deuteranopia-light ef-duo-light ef-light ef-spring ef-summer ef-trio-light)
   "List of symbols with the light Ef themes.")
 
 (defconst ef-themes-dark-themes
-  '(ef-autumn ef-dark ef-deuteranopia-dark ef-duo-dark ef-night ef-winter)
+  '(ef-autumn ef-dark ef-deuteranopia-dark ef-duo-dark ef-night ef-trio-dark ef-winter)
   "List of symbols with the dark Ef themes.")
 
+(defconst ef-themes-collection
+  (append ef-themes-light-themes ef-themes-dark-themes)
+  "Symbols of all the Ef themes.")
+
 (defcustom ef-themes-post-load-hook nil
   "Hook that runs after loading an Ef theme.
 This is used by the commands `ef-themes-select' and
@@ -355,7 +344,9 @@ Run `ef-themes-post-load-hook'."
 ;;;###autoload
 (defun ef-themes-select (theme)
   "Load an Ef THEME using minibuffer completion.
-When called from Lisp, THEME is a symbol."
+When called from Lisp, THEME is a symbol.
+
+Run `ef-themes-post-load-hook' after loading the theme."
   (interactive (list (ef-themes--select-prompt)))
   (ef-themes--load-theme theme))
 
@@ -373,7 +364,9 @@ When called from Lisp, THEME is a symbol."
 If `ef-themes-to-toggle' does not specify two Ef themes, inform
 the user about it while prompting with completion for a theme
 among our collection (this is practically the same as the
-`ef-themes-select' command)."
+`ef-themes-select' command).
+
+Run `ef-themes-post-load-hook' after loading the theme."
   (interactive)
   (if-let* ((themes (ef-themes--toggle-theme-p))
             (one (car themes))
@@ -407,7 +400,9 @@ With optional VARIANT as either `light' or `dark', limit the set
 to the relevant themes.
 
 When called interactively, VARIANT is the prefix argument which
-prompts with completion for either `light' or `dark'."
+prompts with completion for either `light' or `dark'.
+
+Run `ef-themes-post-load-hook' after loading the theme."
   (interactive
    (list
     (when current-prefix-arg
@@ -829,6 +824,10 @@ Helper function for `ef-themes-preview-colors'."
     `(diredfl-write-priv ((,c :foreground ,rainbow-2)))
 ;;;; dirvish
     `(dirvish-hl-line ((,c :background ,bg-hl-line)))
+;;;; display-fill-column-indicator-mode
+    ;; NOTE 2022-09-14: We use the bg-alt mapping as the border mapping
+    ;; is for the `vertical-border'.  We want this to be more subtle.
+    `(fill-column-indicator ((,c :height 1 :background ,bg-alt :foreground ,bg-alt)))
 ;;;; doom-modeline
     `(doom-modeline-bar ((,c :background ,bg-accent)))
     `(doom-modeline-bar-inactive ((,c :background ,bg-alt)))
@@ -1053,8 +1052,8 @@ Helper function for `ef-themes-preview-colors'."
 ;;;; isearch, occur, and the like
     `(isearch ((,c :background ,bg-yellow :foreground ,fg-intense)))
     `(isearch-fail ((,c :background ,bg-red :foreground ,fg-intense)))
-    `(isearch-group-1 ((,c :background ,bg-magenta :foreground ,fg-intense)))
-    `(isearch-group-2 ((,c :background ,bg-green :foreground ,fg-intense)))
+    `(isearch-group-1 ((,c :background ,bg-green :foreground ,fg-intense)))
+    `(isearch-group-2 ((,c :background ,bg-magenta :foreground ,fg-intense)))
     `(lazy-highlight ((,c :background ,bg-blue :foreground ,fg-intense)))
     `(match ((,c :background ,bg-alt :foreground ,fg-intense)))
     `(query-replace ((,c :background ,bg-red :foreground ,fg-intense)))
@@ -1414,7 +1413,6 @@ Helper function for `ef-themes-preview-colors'."
     `(org-modern-date-active ((,c :inherit (ef-themes-fixed-pitch org-modern-label) :background ,bg-alt)))
     `(org-modern-date-inactive ((,c :inherit (ef-themes-fixed-pitch org-modern-label) :background ,bg-dim :foreground ,fg-dim)))
     `(org-modern-done ((,c :inherit org-modern-label :background ,bg-info :foreground ,info)))
-    `(org-modern-label (( )))
     `(org-modern-priority ((,c :inherit (org-modern-label org-priority) :background ,bg-dim)))
     `(org-modern-statistics ((,c :inherit org-modern-label :background ,bg-dim)))
     `(org-modern-tag ((,c :inherit (org-modern-label org-tag) :background ,bg-dim)))
@@ -1488,8 +1486,8 @@ Helper function for `ef-themes-preview-colors'."
     `(recursion-indicator-minibuffer ((,c :foreground ,modeline-info)))
 ;;;; regexp-builder (re-builder)
     `(reb-match-0 ((,c :background ,bg-cyan :foreground ,fg-intense)))
-    `(reb-match-1 ((,c :background ,bg-magenta :foreground ,fg-intense)))
-    `(reb-match-2 ((,c :background ,bg-red :foreground ,fg-intense)))
+    `(reb-match-1 ((,c :background ,bg-red :foreground ,fg-intense)))
+    `(reb-match-2 ((,c :background ,bg-magenta :foreground ,fg-intense)))
     `(reb-match-3 ((,c :background ,bg-yellow :foreground ,fg-intense)))
     `(reb-regexp-grouping-backslash ((,c :inherit font-lock-regexp-grouping-backslash)))
     `(reb-regexp-grouping-construct ((,c :inherit font-lock-regexp-grouping-construct)))
@@ -1602,6 +1600,8 @@ Helper function for `ef-themes-preview-colors'."
     `(vc-dir-status-warning ((,c :inherit error)))
     `(vc-conflict-state ((,c :inherit error)))
     `(vc-edited-state ((,c :inherit italic)))
+    `(vc-git-log-edit-summary-max-warning ((,c :background ,bg-err :foreground ,err)))
+    `(vc-git-log-edit-summary-target-warning ((,c :background ,bg-warning :foreground ,warning)))
     `(vc-locally-added-state ((,c :inherit italic)))
     `(vc-locked-state ((,c :inherit success)))
     `(vc-missing-state ((,c :inherit error)))
